import clsx from 'clsx';
import Link from '@docusaurus/Link';
import useDocusaurusContext from '@docusaurus/useDocusaurusContext';
import Layout from '@theme/Layout';
import HomepageFeatures from '@site/src/components/HomepageFeatures';

import Heading from '@theme/Heading';
import styles from './index.module.css';

function HomepageHeader() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <header className={clsx('hero hero--primary', styles.heroBanner)}>
      <div className="container">
        <Heading as="h1" className="hero__title">
          Yehor Vialov
        </Heading>
        <p className="hero__subtitle">Public Profiles</p>
        <div className={styles.buttons}>
          <Link
            className="button button--secondary button--lg"
            to="https://git.nicelycomposed.codes/yehor">
            Git
          </Link>
          <Link
            className="button button--secondary button--lg"
            to="https://techhub.social/@estevez">
            Mastodon
          </Link>
          <Link
            className="button button--secondary button--lg"
            to="https://pixelfed.social/estevez">
            Pixelfed
          </Link>
          <Link
            className="button button--secondary button--lg"
            to="https://github.com/estevez-dev">
            GitHub
          </Link>
          <Link
            className="button button--secondary button--lg"
            to="https://untappd.com/user/estevezz">
            Untappd
          </Link>
          <Link
            className="button button--secondary button--lg"
            to="https://www.linkedin.com/in/yehor-vialov-2a362158/">
            LinkedIn
          </Link>
        </div>
      </div>
    </header>
  );
}

export default function Home() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <Layout
      title={`Yehor Vialov. Personal website`}
      description="Yehor Vialov's personal website">
      <HomepageHeader />
      <main>
        <HomepageFeatures />
      </main>
    </Layout>
  );
}
